Security Advisories (1)
CPANSA-Dancer2-2018-01 (2018-01-30)

There is a potential RCE with regards to Storable. We have added session ID validation to the session engine so that session backends based on Storable can reject malformed session IDs that may lead to exploitation of the RCE.

NAME

Dancer2::Core::Role::ConfigReader - Config role for Dancer2 core objects

VERSION

version 0.202000

DESCRIPTION

Provides a config attribute that feeds itself by finding and parsing configuration files.

Also provides a setting() method which is supposed to be used by externals to read/write config entries.

ATTRIBUTES

location

Absolute path to the directory where the server started.

config_location

Gets the location from the configuration. Same as $object->location.

environments_location

Gets the directory were the environment files are stored.

config

Returns the whole configuration.

environments

Returns the name of the environment.

config_files

List of all the configuration files.

METHODS

settings

Alias for config. Equivalent to <<$object->config>>.

setting

Get or set an element from the configuration.

has_setting

Verifies that a key exists in the configuration.

load_config_file

Load the configuration files.

AUTHOR

Dancer Core Developers

COPYRIGHT AND LICENSE

This software is copyright (c) 2016 by Alexis Sukrieh.

This is free software; you can redistribute it and/or modify it under the same terms as the Perl 5 programming language system itself.